@@ -9,7 +9,7 @@ def load_env_var(filepath: str) -> (str, str):
     projectroot = os.path.dirname(os.path.dirname(os.path.realpath(filepath)))
 
     envloaded = os.environ.get('ENV_LOADED', False)
-    if envloaded:
+    if not envloaded:
         dotenv_path = os.path.join(projectroot, '.env')
         load_dotenv(dotenv_path)
         envtype = os.environ.get('ENV_TYPE', default='local')
