@@ -6,6 +6,7 @@ from typing import Generator, Iterable, List, Tuple, Union
 import shapely.geometry
 from shapely.geometry.base import BaseGeometry
 import shapely.ops
+import shapely.wkb
 import shapely.wkt
 
 LONLAT_CENTER = (5.74626, 45.17475)
@@ -143,6 +144,12 @@ def encode_geometry(geometry: Union[BaseGeometry, str]) -> str:
     return '{};{}'.format('SRID={}'.format(SRID), geometry)
 
 
+def encode_geometry_bytes(geometry: Union[BaseGeometry, str]) -> str:
+    if not isinstance(geometry, BaseGeometry):
+        geometry = decode_geometry(geometry)
+    return shapely.wkb.dumps(geometry, srid=SRID)
+
+
 def decode_geometry(wkt: str) -> BaseGeometry:
     geom = None
     try:
@@ -153,3 +160,12 @@ def decode_geometry(wkt: str) -> BaseGeometry:
         except:
             pass
     return geom
+
+
+def decode_geometry_bytes(wkb: bytes) -> BaseGeometry:
+    geom = None
+    try:
+        geom = shapely.wkb.loads(wkb)
+    except:
+        pass
+    return geom
